@@ -2,9 +2,9 @@ import eons
 import sys
 import logging
 
-#Try resolving a ModuleNotFoundError by installing the module through our repo.
+# Try resolving a ModuleNotFoundError by installing the module through our repo.
 class install_from_repo(eons.ErrorResolution):
-	def __init__(this, name="install_with_pip"):
+	def __init__(this, name="install_from_repo"):
 		super().__init__(name)
 
 		this.ApplyTo('HelpWantedWithRegistering', "Trying to get SelfRegistering OBJECT")
